@@ -22,6 +22,8 @@
 
 #include "oauthwizard.h"
 
+#include <QtCore/QUrl>
+
 const QByteArray OauthWizard::TwitterRequestTokenURL = "https://twitter.com/oauth/request_token";
 const QByteArray OauthWizard::TwitterAccessTokenURL  = "https://twitter.com/oauth/access_token";
 const QByteArray OauthWizard::TwitterAuthorizeURL    = "https://twitter.com/oauth/authorize";
@@ -217,7 +219,7 @@ void OauthWizard::_authorize(void)
 
 void OauthWizard::_saveTokens(void)
 {
-    if(Account::instance()->userExists(QString(screenName)))
+    if(AccountManager::instance()->userExists(QString(screenName)))
     {
         #ifdef Q_WS_MAEMO_5
                 QMaemo5InformationBox::information(NULL, "User already created.",QMaemo5InformationBox::DefaultTimeout);
@@ -226,7 +228,7 @@ void OauthWizard::_saveTokens(void)
         return;
     }
 
-    Account::instance()->saveNewAccount(QString(screenName), QString(token), QString(tokenSecret));
+    AccountManager::instance()->saveNewAccount(QString(screenName), QString(token), QString(tokenSecret));
 
     // Add new account to the list
     emit newAccount();
