@@ -24,7 +24,12 @@
 #define TWITTERAPPLICATIONITEM_H
 
 #include <QtCore/QObject>
-#include <QtGui/QGraphicsWidget>
+
+#include <QtGui/QDesktopWidget>
+#include <QtGui/QApplication>
+
+#include "loader.h"
+
 #include <QDebug>
 
 /*!
@@ -45,11 +50,20 @@ class TwitterApplicationItem : public QGraphicsWidget
 
 public:
     TwitterApplicationItem(QGraphicsWidget *parent = 0);
-    ~TwitterApplicationItem();
+    void loaderEntryAnimation(void);
+    void loaderExitAnimation(void);
+    QPointF getLoaderPos(void);
+    void setLoaderPosition(QPointF pos);
+    void setLoaderPosition(int x, int y);
 
 private:
-    int _width;
-    int _height;
+    void _createLoader(void);
+
+private slots:
+    void _deleteLoader(void);
+
+protected:
+    Loader *_loader;
 };
 
 #endif //TWITTERAPPLICATIONITEM_H
